##  Creating a Template
By default, only admins can create templates for architecture decisions. However, they can grant full permissions to non-admin roles. For details, see [Permissions](https://help.sap.com/docs/leanix/ea/architecture-decision-templates?locale=en-US&state=PRODUCTION&version=CLOUD#loio2758b4647a4410149f75c5924afeff4b__permissions).
To create an architecture decision template, follow these steps:
  1. On the navigation bar, choose More > Architecture Decisions.
  2. On the left-side panel, choose Templates.
  3. In the upper-right corner, click New Decision Template.
  4. In the upper-left corner of the template page, enter a unique name for the template.
  5. Define the template structure by adding components. To do this, click the arrow next to Add Component, then select the component type. You can delete individual components or change their order when editing a template. To learn more about available components, see [Template Components](https://help.sap.com/docs/leanix/ea/architecture-decision-templates?locale=en-US&state=PRODUCTION&version=CLOUD#loio2758b4647a4410149f75c5924afeff4b__template_components).
  6. Click Save Template.


![Creating an Architecture Decision Template](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio27562d527a441014a5c9a3c89260e2ca_LowRes.gif)
Creating an Architecture Decision Template
The template is created as inactive. To activate the template, enable the corresponding toggle on the templates page. Users can create architecture decisions based on active templates. To learn how to do it, see [Creating an Architecture Decision](https://help.sap.com/docs/leanix/ea/architecture-decisions?locale=en-US&state=PRODUCTION&version=CLOUD#loio2758b7ff7a441014bb6ac52c04964f3b__creating_an_architecture_decision).
![Activating an Architecture Decision Template](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio2741bbde7a4410149e679e79e7023fc3_LowRes.png)
Activating an Architecture Decision Template
